import os
import re

from kubernetes import client, config

config.load_incluster_config()
core_api = client.CoreV1Api()

SECRET_PATTERN: str = os.environ.get('SECRET_PATTERN')
SECRET_KEYS_TO_CHECK = os.environ.get('SECRET_KEYS_TO_CHECK', "").split()
SECRET_NAMESPACE = os.environ.get('SECRET_NAMESPACE', "")


def list_secrets(secret_pattern, namespace):
    secret_names = []
    secrets = core_api.list_namespaced_secret(namespace)

    for secret in secrets.items:
        if re.search(secret_pattern, secret.metadata.name):
            print(f'Found secret: \'{secret.metadata.name}\'') 
            secret_names.append(secret.metadata.name)

    return secret_names


def test_secret_content():
    """
    Gets all secrets that follow the SECRET_PATTERN and 
    checks for the existence of the fields specified in SECRET_KEYS_TO_CHECK
    :return: None
    """

    if not SECRET_PATTERN:
        raise ValueError(f'invalid value found for the following environment variable: SECRET_PATTERN: {SECRET_PATTERN}')
    
    if not SECRET_NAMESPACE:
        raise ValueError(f'invalid value found for the following environment variable: SECRET_NAMESPACE: {SECRET_NAMESPACE}')
    
    for ex_secret in list_secrets(SECRET_PATTERN, SECRET_NAMESPACE):
        secret = core_api.read_namespaced_secret(ex_secret, SECRET_NAMESPACE).to_dict()['data']
        for key in SECRET_KEYS_TO_CHECK:
            if key not in secret:
                raise RuntimeError(f'key \'{key}\' was not found in secret \'{secret}\'')
            
            print(f'key \'{key}\' found in secret \'{secret}\'')

    assert True
